pub struct CellularAutomaton {
pub x: usize,
pub y: usize,
pub cells: Vec<Vec<i32>>,
pub cell_processor: fn(&Self, usize, usize) -> i32,
/* private fields */
}Fields
x: usizey: usizecells: Vec<Vec<i32>>Field of simulation with self.x and self.y dimensions.
cell_processor: fn(&Self, usize, usize) -> i32Implementations
Sourceimpl CellularAutomaton
Construction
impl CellularAutomaton
Construction
Sourcepub fn new(x: usize, y: usize) -> CellularAutomaton
pub fn new(x: usize, y: usize) -> CellularAutomaton
Constructor with the given dimensions and default (Conway’s game of life) processor.
Sourcepub fn new_with_processor(
x: usize,
y: usize,
processor: fn(c: &CellularAutomaton, x: usize, y: usize) -> i32,
) -> CellularAutomaton
pub fn new_with_processor( x: usize, y: usize, processor: fn(c: &CellularAutomaton, x: usize, y: usize) -> i32, ) -> CellularAutomaton
Constructor with the given dimensions and proccesing lambda.
Sourcepub fn set_processor(
&mut self,
processor: fn(c: &CellularAutomaton, x: usize, y: usize) -> i32,
) -> &mut Self
pub fn set_processor( &mut self, processor: fn(c: &CellularAutomaton, x: usize, y: usize) -> i32, ) -> &mut Self
Sets the cell processor lambda for the automaton.
processor: fn(C:&CellularAutomaton, X:usize, Y:usize) -> NextState:i32
Allows to use multiple strategies for one field, by swapping cell_processor instead of cloning or moving matrices between automatons.
Sourceimpl CellularAutomaton
Core processing
impl CellularAutomaton
Core processing
Sourceimpl CellularAutomaton
Field fillings
impl CellularAutomaton
Field fillings
pub fn randomize_prob(&mut self, alive_probability: f64) -> &mut Self